Module dsl

Module dsl 

Symbiont DSL implementation

This module provides parsing and evaluation capabilities for the Symbiont DSL, enabling declarative agent behavior definitions and runtime execution.

Re-exports

pub use evaluator::AgentInstance;
pub use evaluator::AgentState;
pub use evaluator::DslEvaluator;
pub use evaluator::DslValue;
pub use lexer::Lexer;
pub use parser::Parser;
pub use ast::*;

Modules

agent_composition
Agent composition builtins for the DSL
ast
Abstract Syntax Tree definitions for the Symbiont DSL
evaluator
DSL Evaluator for the Symbiont REPL
lexer
Lexer for the Symbiont DSL
parser
Parser for the Symbiont DSL
pattern_builtins
Multi-agent pattern builtins for the DSL
reasoning_builtins
Core reasoning builtins for the DSL